==> jc-1.4.0.tar.gz: soot/jimple/parser/node/AGotoStatement.h <==
// public final class soot.jimple.parser.node.AGotoStatement

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class fabb9d082a32f736 soot_jimple_parser_node_AGotoStatement
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class e8a3f91e723387e0 soot_jimple_parser_node_PStatement

// header file dependencies
// @dep_header soot_jimple_parser_node_PStatement

#include "soot/jimple/parser/node/PStatement.h"

#ifndef _JC_soot_jimple_parser_node_AGotoStatement_H_
#define _JC_soot_jimple_parser_node_AGotoStatement_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PGotoStmt$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AGotoStatement$sub_refs	_jc_soot_jimple_parser_node_AGotoStatement$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AGotoStatement$sub_nonrefs	_jc_soot_jimple_parser_node_AGotoStatement$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AGotoStatement$refs	_jc_soot_jimple_parser_node_AGotoStatement$refs;
typedef struct _jc_soot_jimple_parser_node_AGotoStatement$nonrefs	_jc_soot_jimple_parser_node_AGotoStatement$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AGotoStatement$object	_jc_soot_jimple_parser_node_AGotoStatement$object;

typedef const struct _jc_soot_jimple_parser_node_AGotoStatement$vmethods	_jc_soot_jimple_parser_node_AGotoStatement$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AGotoStatement$vtable	_jc_soot_jimple_parser_node_AGotoStatement$vtable;
typedef const struct _jc_soot_jimple_parser_node_AGotoStatement$vtype	_jc_soot_jimple_parser_node_AGotoStatement$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AGotoStatement$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *);
extern void _jc_soot_jimple_parser_node_AGotoStatement$method$_init$5e82fe68b52295c3(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *, struct _jc_soot_jimple_parser_node_PGotoStmt$object *);

// Virtual methods
extern void _jc_soot_jimple_parser_node_AGotoStatement$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AGotoStatement$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *);
extern struct _jc_soot_jimple_parser_node_PGotoStmt$object *_jc_soot_jimple_parser_node_AGotoStatement$method$getGotoStmt$2a73494e7d8147c8(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *);
extern void _jc_soot_jimple_parser_node_AGotoStatement$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AGotoStatement$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
extern void _jc_soot_jimple_parser_node_AGotoStatement$method$setGotoStmt$1cbb44f4d8b0d297(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *, struct _jc_soot_jimple_parser_node_PGotoStmt$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AGotoStatement$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AGotoStatement$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AGotoStatement$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AGotoStatement$method_info$getGotoStmt$2a73494e7d8147c8;
extern _jc_method _jc_soot_jimple_parser_node_AGotoStatement$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AGotoStatement$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AGotoStatement$method_info$setGotoStmt$1cbb44f4d8b0d297;
extern _jc_method _jc_soot_jimple_parser_node_AGotoStatement$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AGotoStatement$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *);
	struct _jc_soot_jimple_parser_node_PGotoStmt$object	*(*getGotoStmt$2a73494e7d8147c8)(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *);
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *);
	void	(*setGotoStmt$1cbb44f4d8b0d297)(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *, struct _jc_soot_jimple_parser_node_PGotoStmt$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *);
};

// Vtable
struct _jc_soot_jimple_parser_node_AGotoStatement$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PStatement$vmethods	soot_jimple_parser_node_PStatement;
	_jc_soot_jimple_parser_node_AGotoStatement$vmethods	soot_jimple_parser_node_AGotoStatement;
};

// Vtype
struct _jc_soot_jimple_parser_node_AGotoStatement$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AGotoStatement$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AGotoStatement$sub_refs {
	struct _jc_soot_jimple_parser_node_PGotoStmt$object	*__5fgotoStmt__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AGotoStatement$refs {
    _jc_soot_jimple_parser_node_AGotoStatement$sub_refs	soot_jimple_parser_node_AGotoStatement;
    _jc_soot_jimple_parser_node_PStatement$sub_refs	soot_jimple_parser_node_PStatement;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AGotoStatement$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AGotoStatement$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PStatement$sub_nonrefs	soot_jimple_parser_node_PStatement;
    _jc_soot_jimple_parser_node_AGotoStatement$sub_nonrefs	soot_jimple_parser_node_AGotoStatement;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AGotoStatement$object {
	_jc_soot_jimple_parser_node_AGotoStatement$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AGotoStatement$vtype	*vtype;
	_jc_soot_jimple_parser_node_AGotoStatement$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AGotoStatement$vtype _jc_soot_jimple_parser_node_AGotoStatement$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AGotoStatement, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AGotoStatement$class_object;

#endif	/* _JC_soot_jimple_parser_node_AGotoStatement_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/parser/node/AGotoStatement.h <==
// public final class soot.jimple.parser.node.AGotoStatement

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class fabb9d082a32f736 soot_jimple_parser_node_AGotoStatement
// @dep_class 73de4e43969ada95 soot_jimple_parser_node_Node
// @dep_class e8a3f91e723387e0 soot_jimple_parser_node_PStatement

// header file dependencies
// @dep_header soot_jimple_parser_node_PStatement

#include "soot/jimple/parser/node/PStatement.h"

#ifndef _JC_soot_jimple_parser_node_AGotoStatement_H_
#define _JC_soot_jimple_parser_node_AGotoStatement_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_jimple_parser_node_Node$object;
struct _jc_soot_jimple_parser_node_PGotoStmt$object;
struct _jc_soot_jimple_parser_node_Switch$object;

// Typedefs
typedef struct _jc_soot_jimple_parser_node_AGotoStatement$sub_refs	_jc_soot_jimple_parser_node_AGotoStatement$sub_refs;
typedef struct _jc_soot_jimple_parser_node_AGotoStatement$sub_nonrefs	_jc_soot_jimple_parser_node_AGotoStatement$sub_nonrefs;
typedef struct _jc_soot_jimple_parser_node_AGotoStatement$refs	_jc_soot_jimple_parser_node_AGotoStatement$refs;
typedef struct _jc_soot_jimple_parser_node_AGotoStatement$nonrefs	_jc_soot_jimple_parser_node_AGotoStatement$nonrefs;
typedef struct _jc_soot_jimple_parser_node_AGotoStatement$object	_jc_soot_jimple_parser_node_AGotoStatement$object;

typedef const struct _jc_soot_jimple_parser_node_AGotoStatement$vmethods	_jc_soot_jimple_parser_node_AGotoStatement$vmethods;
typedef const struct _jc_soot_jimple_parser_node_AGotoStatement$vtable	_jc_soot_jimple_parser_node_AGotoStatement$vtable;
typedef const struct _jc_soot_jimple_parser_node_AGotoStatement$vtype	_jc_soot_jimple_parser_node_AGotoStatement$vtype;

// Constructors
extern void _jc_soot_jimple_parser_node_AGotoStatement$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AGotoStatement$method$_init$5e82fe68b52295c3(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *, struct _jc_soot_jimple_parser_node_PGotoStmt$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_parser_node_AGotoStatement$method$apply$7d8f74ce7309b216(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_soot_jimple_parser_node_AGotoStatement$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_jimple_parser_node_PGotoStmt$object *_jc_soot_jimple_parser_node_AGotoStatement$method$getGotoStmt$2a73494e7d8147c8(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AGotoStatement$method$removeChild$f5fdaab456b88f05(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AGotoStatement$method$replaceChild$f0df61b776b15826(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
extern void _jc_soot_jimple_parser_node_AGotoStatement$method$setGotoStmt$1cbb44f4d8b0d297(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *, struct _jc_soot_jimple_parser_node_PGotoStmt$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_parser_node_AGotoStatement$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_parser_node_AGotoStatement$method_info$apply$7d8f74ce7309b216;
extern _jc_method _jc_soot_jimple_parser_node_AGotoStatement$method_info$clone$b75f2713d6705f70;
extern _jc_method _jc_soot_jimple_parser_node_AGotoStatement$method_info$getGotoStmt$2a73494e7d8147c8;
extern _jc_method _jc_soot_jimple_parser_node_AGotoStatement$method_info$removeChild$f5fdaab456b88f05;
extern _jc_method _jc_soot_jimple_parser_node_AGotoStatement$method_info$replaceChild$f0df61b776b15826;
extern _jc_method _jc_soot_jimple_parser_node_AGotoStatement$method_info$setGotoStmt$1cbb44f4d8b0d297;
extern _jc_method _jc_soot_jimple_parser_node_AGotoStatement$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_parser_node_AGotoStatement$vmethods {
	void	(*apply$7d8f74ce7309b216)(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *) _JC_JCNI_ATTR;
	struct _jc_soot_jimple_parser_node_PGotoStmt$object	*(*getGotoStmt$2a73494e7d8147c8)(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *) _JC_JCNI_ATTR;
	void	(*removeChild$f5fdaab456b88f05)(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*replaceChild$f0df61b776b15826)(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *, struct _jc_soot_jimple_parser_node_Node$object *, struct _jc_soot_jimple_parser_node_Node$object *) _JC_JCNI_ATTR;
	void	(*setGotoStmt$1cbb44f4d8b0d297)(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *, struct _jc_soot_jimple_parser_node_PGotoStmt$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_parser_node_AGotoStatement$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_parser_node_AGotoStatement$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_parser_node_Node$vmethods	soot_jimple_parser_node_Node;
	_jc_soot_jimple_parser_node_PStatement$vmethods	soot_jimple_parser_node_PStatement;
	_jc_soot_jimple_parser_node_AGotoStatement$vmethods	soot_jimple_parser_node_AGotoStatement;
};

// Vtype
struct _jc_soot_jimple_parser_node_AGotoStatement$vtype {
	_jc_type			type;
	_jc_soot_jimple_parser_node_AGotoStatement$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AGotoStatement$sub_refs {
	struct _jc_soot_jimple_parser_node_PGotoStmt$object	*__5fgotoStmt__5f;
};

// Reference instance fields (object)
struct _jc_soot_jimple_parser_node_AGotoStatement$refs {
    _jc_soot_jimple_parser_node_AGotoStatement$sub_refs	soot_jimple_parser_node_AGotoStatement;
    _jc_soot_jimple_parser_node_PStatement$sub_refs	soot_jimple_parser_node_PStatement;
    _jc_soot_jimple_parser_node_Node$sub_refs	soot_jimple_parser_node_Node;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_parser_node_AGotoStatement$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_parser_node_AGotoStatement$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_parser_node_Node$sub_nonrefs	soot_jimple_parser_node_Node;
    _jc_soot_jimple_parser_node_PStatement$sub_nonrefs	soot_jimple_parser_node_PStatement;
    _jc_soot_jimple_parser_node_AGotoStatement$sub_nonrefs	soot_jimple_parser_node_AGotoStatement;
};

// Object instance structure
struct _jc_soot_jimple_parser_node_AGotoStatement$object {
	_jc_soot_jimple_parser_node_AGotoStatement$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_parser_node_AGotoStatement$vtype	*vtype;
	_jc_soot_jimple_parser_node_AGotoStatement$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_parser_node_AGotoStatement$vtype _jc_soot_jimple_parser_node_AGotoStatement$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_parser_node_AGotoStatement, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_parser_node_AGotoStatement$class_object;

#endif	/* _JC_soot_jimple_parser_node_AGotoStatement_H_ */
